betty.gui.app module - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.gui.app module

Provide the desktop application/Graphical User Interface.

class betty.gui.app.ApplicationConfiguration

  Bases: `BettyMainWindow`

  A window to administer Betty application configuration.

  Parameters:

    - app (`betty.app.App`)

    - parent (`PyQt6.QtCore.QObject` | `None`)

  __init__(app: betty.app.App, *, parent: PyQt6.QtCore.QObject | None = None)
    Parameters:

      - app (`betty.app.App`)

      - parent (`PyQt6.QtCore.QObject` | `None`)

  window_height = 150

    The window’s default height in pixels.

  property window_title: Localizable

    The human-readable short title of this window.

  window_width = 400

    The window’s default width in pixels.

class betty.gui.app.BettyPrimaryWindow

  Bases: `BettyMainWindow`

  A primary, top-level, independent application window.

  Parameters:

    app (`betty.app.App`)

  __init__(app: betty.app.App, /)
    Parameters:

      app (`betty.app.App`)

  clear_caches() → None

    Clear Betty’s caches.

    Return type:

      `None`

  new_project() → None

    Open a window for a new project.

    Return type:

      `None`

  open_application_configuration() → None

    Open the Betty application configuration window.

    Return type:

      `None`

  open_project() → None

    Open a project window.

    Return type:

      `None`

  report_bug() → None

    Open the web page where users can report bugs.

    Return type:

      `None`

  request_feature() → None

    Open the web page where users can request new features.

    Return type:

      `None`

  property window_title: Localizable

    The human-readable short title of this window.

class betty.gui.app.WelcomeWindow

  Bases: `BettyPrimaryWindow`

  The window to show when launching the Betty Graphical User Interface.

  Parameters:

    app (`betty.app.App`)

  __init__(app: betty.app.App)
    Parameters:

      app (`betty.app.App`)

  window_height = 600

    The window’s default height in pixels.

  window_width = 1

    The window’s default width in pixels.